#
# spec file for package pyenv
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define pyenv_dir      %{_libexecdir}/pyenv
#
Name:           pyenv
Version:        2.3.5
Release:        bp155.1.6
Summary:        Python Version Management
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/pyenv/pyenv
Source:         https://github.com/pyenv/pyenv/archive/refs/tags/v%{version}.tar.gz#/pyenv-%{version}.tar.gz
#
BuildRequires:  bash-completion
BuildRequires:  fdupes
BuildRequires:  fish
BuildRequires:  gcc
BuildRequires:  make
BuildRequires:  zsh

%description
pyenv lets the user switch between multiple versions of Python.

This project was forked from rbenv and ruby-build, and modified for Python.

%package bash-completion
Summary:        Bash completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (pyenv and bash-completion)
BuildArch:      noarch

%description bash-completion
Bash command line completion support for %{name}.

%package fish-completion
Summary:        Fish completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (pyenv and fish)
BuildArch:      noarch

%description fish-completion
Fish command line completion support for %{name}.

%package zsh-completion
Summary:        Zsh completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (pyenv and zsh)
BuildArch:      noarch

%description zsh-completion
Zsh command line completion support for %{name}.

%prep
%autosetup -p1 -n %{name}-%{version}

sed -i -e '1s,^#!%{_bindir}/env bash,#!/bin/bash,' libexec/* pyenv.d/exec/pip-rehash/* plugins/python-build/bin/*

%build
##
pushd src
%configure
%make_build
popd

%install
mkdir -p %{buildroot}%{pyenv_dir} \
         %{buildroot}%{pyenv_dir}/plugins \
         %{buildroot}%{pyenv_dir}/shims/ \
         %{buildroot}%{pyenv_dir}/share/python-build/ \
         %{buildroot}%{_sysconfdir}/pyenv.d/ \
         %{buildroot}%{_bindir}

cp -R libexec %{buildroot}%{pyenv_dir}
cp -R bin %{buildroot}%{pyenv_dir}
cp -a pyenv.d %{buildroot}%{_sysconfdir}/

## Install shell completions:
install -D -m0644 completions/pyenv.bash %{buildroot}%{_datadir}/bash-completion/completions/pyenv
install -D -m0644 completions/pyenv.zsh %{buildroot}%{_sysconfdir}/zsh_completion.d/pyenv
install -D -m0644 completions/pyenv.fish %{buildroot}%{_datadir}/fish/vendor_completions.d/pyenv.fish

## Install manpage
install -D -m0644 man/man1/%{name}.1 %{buildroot}%{_mandir}/man1/%{name}.1
pushd %{buildroot}%{_mandir}/man1/
 ln -s %{name}.1 python-build.1
popd

ln -s %{pyenv_dir}/bin/pyenv %{buildroot}%{_bindir}/pyenv

## python-build
pushd plugins/python-build
 install -m755 bin/* %{buildroot}%{pyenv_dir}/libexec
 cp -a share/python-build %{buildroot}%{pyenv_dir}/share/
popd

%fdupes %{buildroot}%{pyenv_dir}

%files
%doc CHANGELOG.md COMMANDS.md README.md
%license LICENSE
%exclude %{_sysconfdir}/pyenv.d/rehash/*/.gitignore

%config %{_sysconfdir}/pyenv.d/rehash/*.d/default.list
%config %{_sysconfdir}/pyenv.d/exec/pip-rehash.bash
%config %{_sysconfdir}/pyenv.d/rehash/*.bash
%config %{_sysconfdir}/pyenv.d/install/*.bash

%{pyenv_dir}
%dir %{_sysconfdir}/pyenv.d
%dir %{_sysconfdir}/pyenv.d/exec/
%dir %{_sysconfdir}/pyenv.d/rehash/
%dir %{_sysconfdir}/pyenv.d/rehash/*.d/
%dir %{_sysconfdir}/pyenv.d/install/

%{_sysconfdir}/pyenv.d/exec/pip-rehash
%{_bindir}/pyenv
#
%{_mandir}/man1/%{name}.1%{?ext_man}
%{_mandir}/man1/python-build.1%{?ext_man}

%files bash-completion
%{_datadir}/bash-completion/completions/pyenv

%files fish-completion
%{_datadir}/fish/vendor_completions.d/pyenv.fish

%files zsh-completion
%config %{_sysconfdir}/zsh_completion.d/pyenv

%changelog
* Tue Oct 18 2022 Thomas Schraitle <thomas.schraitle@suse.com> - 2.3.5
- Update to 2.3.5
  - Add CPython 3.10.7 by @edgarrmondragon in #2454
  - Docs: update Fish PATH update by @gregorias in #2449
  - Add CPython 3.7.14, 3.8.14 and 3.9.14 by @edgarrmondragon in #2456
  - Update miniconda3-3.9-4.12.0 by @Tsuki in #2460
  - Add CPython 3.11.0rc2 by @ViktorHaag in #2459
  - Add patches for 3.7.14 to support Apple Silicon by @samdoran in #2463
  - Add ability to easily skip all use of Homebrew by @samdoran in #2464
  - Drop Travis integration by @sobolevn in #2468
  - Build CPython 3.12+ with --with-dsymutil in MacOS by @native-api in #2471
  - Add Pyston 2.3.5 by @scop in #2476
  Full Changelog: https://github.com/pyenv/pyenv/compare/v2.3.4...v2.3.5
* Mon Oct  3 2022 Thomas Schraitle <thomas.schraitle@suse.com> - 2.3.4
- Changes in spec file
  Remove patch pyenv-CVE-2022-35861.patch as this was already
  integrated in 2.3.3
  See PR pyenv/pyenv#2412
- Update to 2.3.4
  - Add CPython 3.11.0rc1 by @edgarrmondragon in #2434
  - Add support for multiple versions in pyenv uninstall
    by @hardikpnsp in #2432
  - Add micropython 1.18 and 1.19.1 by @dmitriy-serdyuk in #2443
  - CI: support Micropython, deleted scripts; build with -v
    by @native-api in #2447
  - Re-allow paths in .python-version while still preventing CVE-2022-35861
    by @comrumino in #2442
  - CI: Bump OS versions by @native-api in #2448
  - Add Cinder 3.8 by @filips123 in #2433
  - Add support for multiple versions in pyenv uninstall in #2432
  - Add micropython 1.18 and 1.19.1 in #2443
  - Add Cinder 3.8 in #2433
- Changes in 2.3.3
  - Use version sort in pyenv versions by @fofoni in #2405
  - Add CPython 3.11.0b4 by @majorgreys in #2411
  - Python-build: Replace deprecated git protocol use with https in docs
    by @ssbarnea in #2413
  - Fix relative path traversal due to using version string in path
    by @comrumino in #2412
  - Allow pypy2 and pypy3 patching by @brogon in #2421, #2419
  - Add CPython 3.11.0b5 by @edgarrmondragon in #2420
  - Add GraalPython 22.2.0 by @msimacek in #2425
  - Add CPython 3.10.6 by @edgarrmondragon in #2428
  - Add CPython 3.11.0b4 by @majorgreys in #2411
  - Replace deprecated git protocol use with https
    by @ssbarnea in docs #2413
  - Fix relative path traversal due to using version string in path
    by @comrumino in #2412
  - Fix patterns for pypy2.*/pypy3.* versions by @brogon in #2419
* Mon Oct  3 2022 Thomas Schraitle <thomas.schraitle@suse.com> - 2.3.2
- Spec file changes
  Don't buildrequire Sphinx. This dependency pulls other dependencies
  which makes it impossible to build for Python 3.6 (and openSUSE Leap 15.4).
* Mon Jul 18 2022 Thomas Schraitle <thomas.schraitle@suse.com> - 2.3.2
- Update to 2.3.2
  - Add CPython 3.11.0b2 by @saaketp in #2380
  - Honor CFLAGS_EXTRA for MicroPython #2006 by @yggdr in #2007
  - Add post-install checks for curses, ctypes, lzma, and tkinter
    by @aphedges in #2353
  - Add CPython 3.11.0b3 by @edgarrmondragon in #2382
  - Add flags for Homebrew into python-config --ldflags by @native-api
    in #2384
  - Add CPython 3.10.5 by @illia-v in #2386
  - Add Anaconda 2019.10, 2021.04, 2022.05; support Anaconda in
    add_miniconda.py by @native-api in #2385
  - Add Pyston-2.3.4 by @dand-oss in #2390
  - Update Anaconda3-2022.05 MacOSX arm64 md5 by @bkbncn in #2391
- Fix bsc#1201582 to fix CVE-2022-35861 (from commit 22fa683, file
  pyenv-CVE-2022-35861.patch)
* Wed May  4 2022 Thomas Schraitle <thomas.schraitle@suse.com> - 2.3.0
- Update to 2.3.0
  - Bump openssl 1.1 to 1.1.1n for CPython 3.7 3.8 3.9 by @tuzi3040 in #2276
  - Doc Fix: Escape a hash character causing unwanted GitHub Issue linking by @edrogers in #2282
  - Add CPython 3.9.12 by @saaketp in #2296
  - Add CPython 3.10.4 by @saaketp in #2295
  - Add patch for 3.6.15 to support Xcode 13.3 by @nshine in #2288
  - Add patch for 3.7.12 to support Xcode 13.3 by @samdoran in #2292
  - Add CONTRIBUTING.md by @native-api in #2287
  - Add PyPy 7.3.9 release 2022-03-30 by @dand-oss in #2308
  - Add Pyston 2.3.3 by @scop in #2316
  - Add CPython 3.11.0a7 by @illia-v in #2315
  - Add "nogil" Python v3.9.10 by @colesbury in #2342
  - Support XCode 13.3 in all releases that officially support MacOS 11 by @native-api in #2344
  - Add GraalPython 22.1.0 by @msimacek in #2346
  - Make PYENV_DEBUG imply -v for pyenv install by @native-api in #2347
  - Simplify init scheme by @native-api in #2310
  - Don't use Homebrew outside of MacOS by @native-api in #2349
  - Add :latest syntax to documentation for the install command by @hay in #2351
* Tue Apr  5 2022 Thomas Schraitle <thomas.schraitle@suse.com> - 2.2.5
- Update to 2.2.5
  - fix issue 2236 for CPython 3.6.15 and 3.7.12 by @fofoni in #2237
  - python-build: add URL for get-pip for Python 3.6 by @fofoni in #2238
  - Add pyston-2.3.2 by @dmrlawson in #2240
  - CPython 3.11.0a5 by @saaketp in #2241
  - CPython 3.11.0a6 by @saaketp in #2266
  - Add miniconda 4.11.0 by @aphedges in #2268
  - docs(pyenv-prefix): note support for multiple versions by @scop in #2270
  - pypy 7.3.8 02/20/2022 release by @dand-oss in #2253
* Fri Feb 25 2022 Matej Cepl <mcepl@suse.com>
- Put fish completions in thr right directory.
  We don't have to worry about conflicting files, because fish
  has a special directory for vendor completions which have
  precedence over the fish native ones.
* Thu Feb 24 2022 Matej Cepl <mcepl@suse.com>
- Fix tarball name and version.
* Fri Feb 18 2022 Thomas Schraitle <thomas.schraitle@suse.com> - 2.2.4
- Install fish completion into directory '/usr/share/fish/completions' (bsc#1196047)
- Apply spec-cleaner
- Update to 2.2.4
  - Added docstrings to several undocumented functions by @fluencydoc (#2197)
  - Fix incorrect pypy 2.7-7.3.6 sha256 hashes by @joestrach in (#2208)
  - Fix a regression in include paths when compiling ctypes in 3.6.15/3.7.12 by @chipx86 (#2209)
  - Revert "Disable coreutils on M1 Apple Silicon with arm64 (#2020)" by @native-api (#2212)
  - CPython 3.11.0a4 by @nedbat in (#2217)
  - CPython 3.9.10 and 3.10.2 by @nedbat in (#2219)
  - miniconda3-latest: added Linux-aarch64 by @verdimrc (#2221)
  - Add GraalPython 22.0.0 by @msimacek in (#2226)
  - Full changelog at https://github.com/pyenv/pyenv/releases/tag/v2.2.4-1
- Update to 2.2.3
  - Add new pypy versions (pypy2.7-7.3.2~7.3.5) to the version list (#2194)
  - Fix Python 3.7.12 compilation on macOS arm64/M1. (#2190)
  - Fix Python 3.6.15 compilation on macOS arm64/M1. (#2189)
  - Add Anaconda3-2021.11 (#2193)
  - CPython 3.11.0a3 (#2187)
  - Fix errant "echo" in README install instructions (#2185)
  - Add Miniforge and Mambaforge 4.10.3-10 (#2184)
  - Add CPython 3.10.1 (#2183)
  - Fix 3.6.15 build on macOS (#2182)
  - Full changelog at https://github.com/pyenv/pyenv/releases/tag/v2.2.3
- Update to 2.2.2
  - Add support for macOS Apple M1 (#2164)
* Mon Nov 22 2021 Matej Cepl <mcepl@suse.com>
- Remove *rpmlintrc, it is not necessary anymore.
- Remove our own manpage, it is now included in the tarball.
* Mon Nov 22 2021 Alexander Graul <alexander.graul@suse.com>
- Update to 2.2.1:
  - Added documentation for commands
  - Added Python versions (inlcuding 3.10.0)
  - Full changelog at https://github.com/pyenv/pyenv/blob/master/CHANGELOG.md
* Fri May 28 2021 Markéta Machová <mmachova@suse.com>
- Install fish completion to vendor_completions.d (https://github.com/pyenv/pyenv/issues/1944)
* Mon May 24 2021 Chris Coutinho <chrisbcoutinho@gmail.com>
- Update to 2.0.0
  Primary breaking change: Split startup logic into PATH and everything else
  For details check the CHANGELOG:
  https://github.com/pyenv/pyenv/blob/master/CHANGELOG.md
* Mon May  3 2021 Malte Ohmstede <malte.ohmstede@gmail.com>
- Update to 1.2.27
  * Add GraalPython 21.1.0 (#1882)
  * Add CPython 3.10.0a7 (#1880)
  * Docs(README): fix info about version-file separator (#1874)
  * List versions starting with a dot (#1350)
  * Feat: support (skip) commented lines in version-file (#1866)
  * pypy3.7-7.3.4 (#1873)
  * Create miniforge3-4.10 (#1868)
  * Add CPython 3.9.4 (#1865)
- Update to 1.2.26
  * Add CPython 3.9.4 (#1865)
- Update to 1.2.25
  * bpo-43631: update to openssl 1.1.1k (#1861)
  * Add CPython 3.9.3 and 3.8.9 (#1859)
  * Add micropython 1.14 (#1858)
  * Shell detect improvements (#1835)
  * Test(init): remove misleading detect from parent shell case arg (#1856)
  * Add GraalPython 21.0.0 (#1855)
- Update to 1.2.24.1
  * Updated CHANGELOG.MD to reflect latest changes at v1.2.24
  * Fixed pyenv --version to display the correct pyenv version
- Update to 1.2.24
  * GitHub Actions: Add $PYENV_ROOT/shims to $PATH (#1838)
  * Add Python 3.10.0a6 (#1839)
  * Remove the "Using script's directory as PYENV_DIR if shim is invoked with a script argument" feature (#1814)
  * Update GET_PIP_URL (#1844)
  * GitHub Action to build Python versions on Ubuntu (#1794)
  * Make work in nounset (-u) mode (#1786)
  * Update miniforge3-4.9.2 (#1834)
  * Added aarch64 for Linux in anaconda_architecture() (#1833)
  * Hook script to add latest suffix for install command (#1831)
  * Fix error link (#1832)
  * Clarify proxy variable names in readme (#1830)
  * Travis CI: Add Xcode 12 on macOS 10.15.5 (#1708)
  * Added --nosystem argument (#1829)
  * Add CPython 3.8.8 (#1825)
  * Add CPython 3.9.2 (#1826)
  * Add manpage (#1790)
- Update to 1.2.23
  * python-build: Add CPython v3.7.10 (#1738)
  * python-build: Add CPython v3.6.13 (#1817)
  * python-build: Add PyPy 3.7-c-jit-latest (#1812)
  * python-build: Add PyPy 3.7 (#1718, #1726, #1780)
  * python-build: Add miniconda3 4.9.2 (#1763)
  * python-build: Add miniconda3 4.8.3 (#1763)
  * python-build: Add miniconda3 4.8.2 (#1763)
  * python-build: Add Miniforge3-4.9.2 (#1782)
  * python-build: Fix download links for some PyPy and Stackless versions (#1692)
  * python-build: Add PYENV_DEBUG option (#1806)
  * python-build: Fix get-pip which dropped support for legacy Python (#1793)
  * pyenv-help: Fix sed: RE error: illegal byte sequence (#1714)
  * pyenv-versions: Fix not printing asterisk for current version in Bash 3 (#1815)
  * pyenv-prefix: "system" python - support cases where python3 is in PATH but not python (#1655)
  * pyenv-which: Added fallback to system executable (#1797)
  * pyenv-rehash: Use associative arrays for better performance on bash >= 4 (#1749)
  * pyenv-rehash: Try to sleep in 0.1 sec steps when acquiring lock (#1798)
  * pyenv: Use a better PS4 as recommended by Bash Hackers Wiki (#1810)
- Update to 1.2.22
  * python-build: Add LDFLAGS for zlib on macOS >= 1100 (#1711)
  * python-build: Add the CPython 3.9.1 (#1752)
  * python-build: Change order of LDFLAGS paths (#1754)
  * python-build: Docker config for testing python-build (#1548)
  * python-build: Put prerequisite for installation before install (#1750)
  * python-build: Add GraalPython 20.3 (#1736)
  * python-build: Add CPython 3.8.7
  * python-build: Added anaconda3-2020.11 (#1774)
  * python-build: Added arm64 architecture support in python-build for macOS (#1775)
- Update to 1.2.21
  * python-build: Add CPython 3.9.0 (#1706)
  * python-build: Add CPython 3.8.6 (#1698)
  * python-build: Add CPython 3.7.9 (#1680)
  * python-build: Add CPython 3.6.12 (#1680)
  * python-build: Add CPython 3.5.10 (#1690)
  * python-build: Add Jython 2.7.2 (#1672)
  * python-build: Add Graalpython 20.1.0 (#1594)
  * python-build: Add Graalpython 20.2.0 (#1594)
  * python-build: Add Anaconda3-2020.07 (#1684)
  * python-build: Add micropython-1.13 (#1704)
  * python-build: Fix PyPy download links (#1682)
  * python-build: Support for PYTHON_BUILD_MIRROR_URL when checksums do not exist (#1673)
  * pyenv: Search for plugins in PYENV_DIR and PYENV_ROOT (#1697)
  * pyenv-help: Fix 'sed: RE error: illegal byte sequence' (#1670)
* Thu Aug  6 2020 Sergio Fenoll <sergio@fenoll.be>
- Update to 1.2.20
  * python-build: Add CPython 3.8.5 (#1667)
  * python-build: Add CPython 3.8.4 (#1658)
  * python-build: Add CPython 3.7.8
  * python-build: Add CPython 3.6.11
  * pyenv-install: Make grep detection more robust (#1663)
  * python-build: Fix has_tar_xz_support function on FreeBSD. (#1652)
- Update to 1.2.19
  * python-build: Add CPython 3.8.3 (#1612)
  * python-build: Add CPython 2.7.18 (#1593)
  * python-build: Add CPython 3.10-dev (#1619)
  * python-build: Add anaconda3-2020.02 (#1584)
  * python-build: Add stackless 3.7.5 (#1589)
- Update to 1.2.18
  * python-build: Update download URLs for old OpenSSL releases (#1578)
  * python-build: Prevent brew: command not found messages that are not errors (#1544)
- Update to 1.2.17
  * python-build: Add CPython 3.8.2
  * python-build: Add CPython 3.7.7 (#1553)
  * python-build: Add Miniconda versions newer than 4.3.30 (#1361)
  * python-build: Add Micropython 1.12 (#1542)
  * python-build: Add Add CPython 3.9.0a4
  * pyenv: Fix sed illegal byte sequence error (#1521)
* Mon Jan 20 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix the tarball url to match reality
* Thu Jan 16 2020 Thomas Schraitle <thomas.schraitle@suse.com> - 1.2.16
- Update to 1.2.16
  * python-build: Add CPython 3.8.1 (#1497)
  * python-build: Add CPython 3.7.6 (#1498)
  * python-build: Add CPython 3.6.10 (#1499)
  * python-build: Add CPython 3.5.9 (#1448)
  * python-build: Add PyPy 7.3.0 (1502)
- Update to 1.2.15
  * python-build: Add CPython 3.7.5 (#1423)
  * python-build: Add CPython 2.7.17 (#1433)
  * python-build: Add CPython 3.5.8 (#1441)
  * python-build: Add PyPy 7.2.0 (#1418)
  * python-build: Add anaconda3-2019.10 (#1427)
  * pyenv-help: Show text for all pyenv commands in pyenv-help (#1421)
- Update to 1.2.14
  * python-build: Add CPython 3.8.0 (#1416)
  * python-build: Add Anaconda-2019.07 (#1382)
  * python-build: Add Micropython 1.11 (#1395)
  * python-build: Fix compatibility issues with Homebrew installed Tcl/Tk (#1397)
  * pyenv-exec: Do not use exec -a, do not mangle PATH for system Python (#1169)
- Spec file
  * Apply spec-cleaner
  * Add version in last changelog entry to avoid rpmlint warnings
* Wed Oct  9 2019 Chris Coutinho <chrisbcoutinho@gmail.com>
- Update to 1.2.13
  * python-build: Add CPython 3.7.4
  * python-build: Add CPython 3.6.9
- Update to 1.2.12
  * python-build: Find zlib from Xcode or brew on Mojave (#1353)
  * python-build: Add PyPy 7.1.1 (#1335)
  * python-build: Add CPython 3.8.0b1
- Update to 1.2.11
  * python-build: Fix posix_close name collision in 2.4 builds (#1321)
  * python-build: Add CPython 3.4.10 (#1322)
  * python-build: Add Anaconda 2019.03
  * python-build: Allow overriding the preference of OpenSSL version per definition basis (#1302, #1325, #1326)
  * python-build: Imported changes from rbenv/ruby-build 20190401 (#1327)
  * python-build: Use GNU Readline 8.0 on macOS if brew's package isn't available (#1329)
- Update to 1.2.10
  * python-build: Force y, Y, yes or YES to confirm installation (#1217)
  * python-build: Add PyPy 7.0.0, 7.1.0
  * python-build: Add CPython 2.7.16, 3.5.7 and 3.7.3
  * python-build: Install python-gdb.py (#1190, #1289)
  * python-build: Add micropython 1.10
  * python-build: Prefer Homebrew's OpenSSL 1.1 over 1.0 (#839, #1302)
* Mon Jan 28 2019 thomas.schraitle@suse.com
- Update to 1.2.9:
  * python-build: Add CPython 3.7.2 and CPython 3.6.8 (#1256)
  * python-build: Add anaconda[23]-5.3.1 (#1246)
  * python-build: Add Anaconda 2018.12 (#1259)
  * python-build: Fix ironpython-dev git repo url (#1260)
  * python-build: Add OPENSSL_NO_SSL3 patch for CPython 3.3.7 (#1263)
- Version 1.2.8:
  * python-build: Add CPython 3.7.1
  * python-build: Add CPython 3.6.7
  * python-build: Add anaconda[23]-5.3.0 (#1220)
* Mon Jan 28 2019 thomas.schraitle@suse.com
- Install fish completion file to /usr/share/fish/completions/
* Thu Nov  8 2018 Antonio Larrosa <alarrosa@suse.com>
- Install bash completion file to /usr/share/bash-completion/completions
  and fix shebangs of several bash scripts.
* Tue Oct 30 2018 Jan Engelhardt <jengelh@inai.de>
- Trim bias from descriptions.
* Tue Oct 16 2018 Jon Brightwell <jon@moozaad.co.uk>
- Update to 1.2.7:
    python-build: Add CPython 3.5.6 (#1199)
    python-build: Add CPython 3.4.9
  1.2.5
    python-build: Add CPython 3.7.0 (#1177)
    python-build: Add micropython 1.9.4 (#1160)
    python-build: Add anaconda[23]-5.2.0 (#1165)
    pyenv: Fix seq(1) is not available on OpenBSD (#1166)
  1.2.4
    python-build: Add CPython 2.7.15
    python-build: Add PyPy 6.0.0
    python-build: Allow overriding HTTP client type based on environment variable PYTHON_BUILD_HTTP_CLIENT (#1126)
    python-build: Use version-specific get-pip.py when installing 2.6 and 3.2 (#1131)
    pyenv: Merge rbenv master (#1151)
    pyenv: Make pyenv-rehash safer for multiple processes (#1092)
* Wed Apr  4 2018 michele.bologna@suse.com
- Update to 1.2.3:
  * python-build: Add CPython 3.6.5
  * python-build: Set openssl PKG_CONFIG_PATH for python 3.7 (#1117)
  * python-build: Add ActivePython versions 2.7.14, 3.5.4, 3.6.0 (#1113)
  * python-build: Unset PIP_VERSION before invoking get-pip.py as a workaround for invalid truth value error (#1124)
* Tue Feb  6 2018 michele.bologna@suse.com
- Changelog for pyenv:
  Update to 1.2.1:
  * python-build: Add CPython 3.6.4
  * python-build: Add PyPy[23] 5.10
* Sun Sep 24 2017 thomas.schraitle@suse.com
  Update to 1.1.4
  * pyenv: Workaround for scripts in $PATH which needs to be
  source'd (#100, #688, #953)
  * python-build: Add support for PyPy3 executables like
  libpypy3-c.so (#955, #956)
  * python-build: Add CPython 2.7.14, 3.4.7, 3.5.4 (#965, #971, #980)
  * python-build: Add Jython 2.7.1 (#973)
  Spec changes:
  * Add pyenv.d/rehash/conda.d/ directory
  * Remove excluding .gitignore
* Sun Sep 17 2017 thomas.schraitle@suse.com
  More changes in the spec file:
  - Corrected path to Python definitions from python-build
  - Fixed install/uninstall and python-build
  They are now installed under libexec, not bin
  - Corrected manpage link creation to pyenv-{install,uninstall}
  - Switched from noarch to arch dependent due to pyenv-realpath.dylib
  - Add missing pyenv.d/rehash/conda.txt
* Sun Sep 17 2017 thomas.schraitle@suse.com
  Update to 1.1.3:
  * python-build: Add CPython 3.6.2 (#951)
  Spec file changes:
  * create manpage
  * subpackages for shell completion scripts
  * use spec-cleaner
  * add -rpmlintrc to suppress false error messages about
  wrong interpreter
  Details between 1.0.8 to 1.1.2, see below:
  v1.1.2:
  * pyenv: Fix incorrect pyenv --version output in v1.1.1 (#947)
  v1.1.1:
  * python-build: Update links to Portable Pypy 5.8-1 bugfix release (#939)
  * This is a minor release to update upstream links to Portable PyPy 5.8-1, see details at:
  squeaky-pl/portable-pypy#54
  v1.1.0:
  * pyenv: Merge rbenv master (#927)
  * python-build: Add PyPy 5.8.0 (#932)
  * python-build: Anaconda[23] 4.4.0 (#930)
  * python-build: Add micropython-dev (#920)
  v1.0.9:
  * fixes #865: Add support for PyPy2 5.7 and PyPy3 5.7
  No public changelog for v1.0.8.
* Fri Apr 28 2017 mbologna@suse.de
- Version bump to 1.0.9
* Mon Feb 20 2017 toms@opensuse.org
  Update to 1.0.7:
  * python-build: Add CPython 3.5.3 (#811)
  * python-build: Add CPython 3.4.6 (#812)
  * python-build: Fix tar.gz checksum of CPython 3.6.0 (#793)
  * python-build: Jython installer workaround (#800)
  * python-build: Disable optimization (-O0) when
  - -debug was specified (#808)
* Thu Jan  5 2017 toms@opensuse.org
- Use spec file from dmacvicar, but:
  - Create additional pyenv.d and plugins directories
- Rewrote spec file from scratch
- Update to 1.0.6
* Wed Mar  2 2016 dmacvicar@suse.de
- update to version 20160202
* Fri Jan  8 2016 dmacvicar@suse.de
- update to version 20151222
* Sat Mar 14 2015 dmacvicar@suse.de
- initial package for 20150226
